package cn.iocoder.yudao.module.reward.service.reward;

import java.util.*;
import javax.annotation.Resource;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.mybatis.core.service.AbstractService;
import cn.iocoder.yudao.module.reward.vo.reward.*;
import cn.iocoder.yudao.module.reward.dal.dataobject.reward.RewardDO;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.module.reward.convert.reward.RewardConvert;
import cn.iocoder.yudao.module.reward.dal.mysql.reward.RewardMapper;
import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.module.reward.enums.ErrorCodeConstants.*;
import static com.baomidou.mybatisplus.core.toolkit.IdWorker.getId;

/**
 * 礼品 Service 实现类
 *
 * @author 系统管理员
 */
@Service
@Validated
public class RewardServiceImpl extends AbstractService<RewardMapper, RewardDO> implements RewardService {

    @Resource
    private RewardMapper rewardMapper;

    @Override
    public Long create(RewardCreateReqVO createReqVO) {
        // 插入
        RewardDO rewardDO = RewardConvert.INSTANCE.convert(createReqVO);
        rewardDO.setCode("111");
        int id = rewardMapper.insert(rewardDO);
        // 返回
        return (long)id;
    }

    @Override
    public void update(RewardUpdateReqVO updateReqVO) {
        // 校验存在
        this.validateExists(updateReqVO.getId());
        // 更新
        RewardDO updateObj = RewardConvert.INSTANCE.convert(updateReqVO);
        rewardMapper.updateById(updateObj);
    }

    @Override
    public void delete(Long id) {
        // 校验存在
        this.validateExists(id);
        // 删除
        rewardMapper.deleteById(id);
    }

    private void validateExists(Long id) {
        if (rewardMapper.selectById(id) == null) {
            throw exception(_NOT_EXISTS);
        }
    }

    @Override
    public RewardDO get(Long id) {
        return rewardMapper.selectById(id);
    }

    @Override
    public List<RewardDO> getList(Collection<Long> ids) {
        return rewardMapper.selectBatchIds(ids);
    }

    @Override
    public PageResult<RewardDO> getPage(RewardQueryVO query, PageVO page) {
        return rewardMapper.selectPage(page, query);
    }

    @Override
    public List<RewardDO> getList(RewardQueryVO query) {
        return rewardMapper.selectList(query);
    }

    //生成礼品ID
    private String generateRewardCode(){
        return String.valueOf(getId());
    }
}
